@@ -22,6 +22,9 @@ if TYPE_CHECKING:
     from tox.tox_env.python.api import Python
 
 
+logger = logging.getLogger(__name__)
+
+
 class UvInstaller(Pip):
     """Pip is a python installer that can install packages as defined by PEP-508 and PEP-517."""
 
@@ -88,7 +91,7 @@ class UvInstaller(Pip):
         elif isinstance(arguments, Sequence):  # pragma: no branch
             self._install_list_of_deps(arguments, section, of_type)
         else:  # pragma: no cover
-            logging.warning("uv cannot install %r", arguments)  # pragma: no cover
+            logger.warning("uv cannot install %r", arguments)  # pragma: no cover
             raise SystemExit(1)  # pragma: no cover
 
     def _install_list_of_deps(  # noqa: C901
@@ -112,7 +115,7 @@ class UvInstaller(Pip):
                 groups["req"].extend(str(i) for i in arg.deps)
                 groups["dev_pkg"].append(str(arg.path))
             else:  # pragma: no branch
-                logging.warning("uv install %r", arg)  # pragma: no cover
+                logger.warning("uv install %r", arg)  # pragma: no cover
                 raise SystemExit(1)  # pragma: no cover
         req_of_type = f"{of_type}_deps" if groups["pkg"] or groups["dev_pkg"] else of_type
         for value in groups.values():
