@@ -10,6 +10,7 @@ from pathlib import Path
 from platform import python_implementation
 from typing import TYPE_CHECKING, Any, Literal, Optional, Type, cast  # noqa: UP035
 
+from tox.config.loader.str_convert import StrConvert
 from tox.execute.local_sub_process import LocalSubProcessExecutor
 from tox.execute.request import StdinSource
 from tox.tox_env.errors import Skip
@@ -56,10 +57,19 @@ class UvVenv(Python, ABC):
             default=False,
             desc="add seed packages to the created venv",
         )
+        self.conf.add_config(
+            keys=["system_site_packages", "sitepackages"],
+            of_type=bool,
+            default=lambda conf, name: StrConvert().to_bool(  # noqa: ARG005
+                self.environment_variables.get("VIRTUALENV_SYSTEM_SITE_PACKAGES", "False"),
+            ),
+            desc="create virtual environments that also have access to globally installed packages.",
+        )
+
         # The cast(...) might seems superfluous but removing it makes mypy crash. The problem isy on tox typing side.
         self.conf.add_config(
             keys=["uv_python_preference"],
-            of_type=cast(Type[Optional[PythonPreference]], Optional[PythonPreference]),  # noqa: UP006
+            of_type=cast("Type[Optional[PythonPreference]]", Optional[PythonPreference]),  # noqa: UP006
             default=None,
             desc=(
                 "Whether to prefer using Python installations that are already"
@@ -156,7 +166,7 @@ class UvVenv(Python, ABC):
 
     @property
     def venv_dir(self) -> Path:
-        return cast(Path, self.conf["env_dir"])
+        return cast("Path", self.conf["env_dir"])
 
     @property
     def environment_variables(self) -> dict[str, str]:
@@ -182,21 +192,28 @@ class UvVenv(Python, ABC):
         elif (base.major, base.minor) == sys.version_info[:2] and (sys.implementation.name.lower() == imp):
             version_spec = sys.executable
         else:
-            uv_imp = "" if (imp and imp == "cpython") else imp
-            version_spec = f"{uv_imp or ''}{base.major}.{base.minor}" if base.minor else f"{uv_imp or ''}{base.major}"
+            uv_imp = imp or ""
+            if not base.major:
+                version_spec = uv_imp
+            elif not base.minor:
+                version_spec = f"{uv_imp}{base.major}"
+            else:
+                version_spec = f"{uv_imp}{base.major}.{base.minor}"
 
         cmd: list[str] = [self.uv, "venv", "-p", version_spec, "--allow-existing"]
         if self.options.verbosity > 3:  # noqa: PLR2004
             cmd.append("-v")
         if self.conf["uv_seed"]:
             cmd.append("--seed")
+        if self.conf["system_site_packages"]:
+            cmd.append("--system-site-packages")
         if self.conf["uv_python_preference"]:
             cmd.extend(["--python-preference", self.conf["uv_python_preference"]])
         cmd.append(str(self.venv_dir))
         outcome = self.execute(cmd, stdin=StdinSource.OFF, run_id="venv", show=None)
 
         if self.core["skip_missing_interpreters"] and outcome.exit_code == 1:
-            msg = "could not find python interpreter with spec(s):" f" {version_spec}"
+            msg = f"could not find python interpreter with spec(s): {version_spec}"
             raise Skip(msg)
 
         outcome.assert_success()
