@@ -12,6 +12,7 @@ from importlib.metadata import version
 from typing import TYPE_CHECKING, get_args
 
 import pytest
+import tox.tox_env.errors
 
 from tox_uv._venv import PythonPreference
 
@@ -54,6 +55,90 @@ def test_uv_venv_spec_major_only(tox_project: ToxProjectCreator) -> None:
     result.assert_success()
 
 
+@pytest.mark.parametrize(
+    ("pypy", "expected_uv_pypy"),
+    [
+        ("pypy", "pypy"),
+        ("pypy9", "pypy9"),
+        ("pypy999", "pypy9.99"),
+        ("pypy9.99", "pypy9.99"),
+    ],
+)
+def test_uv_venv_spec_pypy(
+    capfd: pytest.CaptureFixture[str],
+    tox_project: ToxProjectCreator,
+    pypy: str,
+    expected_uv_pypy: str,
+) -> None:
+    """Validate that major and minor versions are correctly applied to implementations.
+
+    This test prevents a regression that occurred when the testenv name was "pypy":
+    the uv runner was asked to use "pypyNone" as the Python version.
+
+    The test is dependent on what PyPy interpreters are installed on the system;
+    if any PyPy is available then the "pypy" value will not raise a Skip exception,
+    and STDOUT will be captured in `result.out`.
+
+    However, it is expected that no system will have PyPy v9.x installed,
+    so STDOUT must be read from `capfd` after the Skip exception is caught.
+
+    Since it is unknown whether any PyPy interpreter will be installed,
+    the `else` block's branch coverage is disabled.
+    """
+
+    project = tox_project({"tox.ini": f"[tox]\nenv_list = {pypy}"})
+    try:
+        result = project.run("config", "-vv")
+    except tox.tox_env.errors.Skip:
+        stdout, _ = capfd.readouterr()
+    else:  # pragma: no cover (PyPy might not be available on the system)
+        stdout = result.out
+    assert "pypyNone" not in stdout
+    assert f"-p {expected_uv_pypy} " in stdout
+
+
+@pytest.mark.parametrize(
+    ("implementation", "expected_implementation", "expected_name"),
+    [
+        ("", "cpython", "cpython"),
+        ("py", "cpython", "cpython"),
+        ("pypy", "pypy", "pypy"),
+    ],
+)
+def test_uv_venv_spec_full_implementation(
+    tox_project: ToxProjectCreator,
+    implementation: str,
+    expected_implementation: str,
+    expected_name: str,
+) -> None:
+    """Validate that Python implementations are explicitly passed to uv's `-p` argument.
+
+    This test ensures that uv searches for the target Python implementation and version,
+    even if another implementation -- with the same language version --
+    is found on the path first.
+
+    This prevents a regression to a bug that occurred when PyPy 3.10 was on the PATH
+    and tox was invoked with `tox -e py3.10`:
+    uv was invoked with `-p 3.10` and found PyPy 3.10, not CPython 3.10.
+    """
+
+    project = tox_project({})
+    result = project.run("run", "-vve", f"{implementation}9.99")
+
+    # Verify that uv was invoked with the full Python implementation and version.
+    assert f" -p {expected_implementation}9.99 " in result.out
+
+    # Verify that uv interpreted the `-p` argument as a Python spec, not an executable.
+    # This confirms that tox-uv is passing recognizable, usable `-p` arguments to uv.
+    assert f"no interpreter found for {expected_name} 9.99" in result.err.lower()
+
+
+def test_uv_venv_system_site_packages(tox_project: ToxProjectCreator) -> None:
+    project = tox_project({"tox.ini": "[testenv]\npackage=skip\nsystem_site_packages=true"})
+    result = project.run("-vv")
+    result.assert_success()
+
+
 @pytest.fixture
 def other_interpreter_exe() -> pathlib.Path:  # pragma: no cover
     """Returns an interpreter executable path that is not the exact same as `sys.executable`.
